#!/usr/bin/perl

use strict;
use warnings;
use utf8;
use lib qw(lib);

use IdPAccountManager::Configuration;
use IdPAccountManager::WebRequest;

## Defining parameters format
my $urn_or_url_regex = '(http(s?):\/\/|urn:)[^\\\$\*\"\'\`\^\|\<\>\n\s]+'
  ;    ## Format de type URL HTTP ou URN
my $url_regex     = 'http(s?):\/\/[^\\\$\*\"\'\`\^\|\<\>\n\s]+';
my $email_regex   = '([\w\-\_\.\/\+\=\'\&]+|\".*\")\@[\w\-]+(\.[\w\-]+)+';
my $domains_regex = '[\w\.\-]+(,[\w\.\-]+)*';
my %format        = (
    ## URL
    #'attributeauthority' => $url_regex,
    'sp_entityid' => $urn_or_url_regex,
);

my $configuration = IdPAccountManager::Configuration->new(
    file => 'conf/IdPAccountManager.conf'
);

my %actions = (
    'select_sp'      => { 'title_en' => 'Select your Service Provider' },
    'account_wizard' => { 'title_en' => 'Select your Service Provider' },
    'generate_token' => { 'title_en' => 'Generate an authentication token' },
    'validate_token' => { 'title_en' => 'Complete Email Challenge' },
    'home'           => { 'title_en' => $configuration->{app_name} },
);

## Gives writes for the group
umask 0002;

chdir $configuration->{root_manager_dir};

my $request = new IdPAccountManager::WebRequest(
    actions       => \%actions,
    format        => \%format,
    configuration => $configuration
);

if (defined $request) {
    $request->execute();
}

$request->respond();

__END__

=head1 NAME

account-manager-web.pl - Web interface for the Test IdP Account Manager
